# coding: utf-8

"""
    wwtp-paas-main-bus-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from dhicn_wwtp_data_bus_service.api_client import ApiClient
from dhicn_wwtp_data_bus_service.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class GeneralDataApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def api_general_data_get_assembly_configs_get(self, **kwargs):  # noqa: E501
        """根据展示类型获取点位配置信息  # noqa: E501

        根据展示类型获取点位配置信息  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_general_data_get_assembly_configs_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int display_type_enum: 展示类型
        :param str model_name: 模型名称
        :param str product_line: 工艺线
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[AssemblyConfigOutput]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_general_data_get_assembly_configs_get_with_http_info(**kwargs)  # noqa: E501

    def api_general_data_get_assembly_configs_get_with_http_info(self, **kwargs):  # noqa: E501
        """根据展示类型获取点位配置信息  # noqa: E501

        根据展示类型获取点位配置信息  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_general_data_get_assembly_configs_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int display_type_enum: 展示类型
        :param str model_name: 模型名称
        :param str product_line: 工艺线
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[AssemblyConfigOutput], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'display_type_enum',
            'model_name',
            'product_line'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_general_data_get_assembly_configs_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'display_type_enum' in local_var_params and local_var_params['display_type_enum'] is not None:  # noqa: E501
            query_params.append(('displayTypeEnum', local_var_params['display_type_enum']))  # noqa: E501
        if 'model_name' in local_var_params and local_var_params['model_name'] is not None:  # noqa: E501
            query_params.append(('modelName', local_var_params['model_name']))  # noqa: E501
        if 'product_line' in local_var_params and local_var_params['product_line'] is not None:  # noqa: E501
            query_params.append(('productLine', local_var_params['product_line']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/GeneralData/GetAssemblyConfigs', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[AssemblyConfigOutput]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_general_data_get_inlet_wq_get(self, **kwargs):  # noqa: E501
        """获取进水水质数据，包括原始数据和清洗后数据 Get inlet water quality data, including source data and processed data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_general_data_get_inlet_wq_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str start_time: 开始时间 start time
        :param str end_time: 结束时间 end time
        :param str model_name: 模板模型名称 template model name
        :param str product_line: 工艺线代码 product line code
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[InletWqOut]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_general_data_get_inlet_wq_get_with_http_info(**kwargs)  # noqa: E501

    def api_general_data_get_inlet_wq_get_with_http_info(self, **kwargs):  # noqa: E501
        """获取进水水质数据，包括原始数据和清洗后数据 Get inlet water quality data, including source data and processed data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_general_data_get_inlet_wq_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str start_time: 开始时间 start time
        :param str end_time: 结束时间 end time
        :param str model_name: 模板模型名称 template model name
        :param str product_line: 工艺线代码 product line code
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[InletWqOut], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'start_time',
            'end_time',
            'model_name',
            'product_line'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_general_data_get_inlet_wq_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'start_time' in local_var_params and local_var_params['start_time'] is not None:  # noqa: E501
            query_params.append(('startTime', local_var_params['start_time']))  # noqa: E501
        if 'end_time' in local_var_params and local_var_params['end_time'] is not None:  # noqa: E501
            query_params.append(('endTime', local_var_params['end_time']))  # noqa: E501
        if 'model_name' in local_var_params and local_var_params['model_name'] is not None:  # noqa: E501
            query_params.append(('modelName', local_var_params['model_name']))  # noqa: E501
        if 'product_line' in local_var_params and local_var_params['product_line'] is not None:  # noqa: E501
            query_params.append(('productLine', local_var_params['product_line']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/GeneralData/GetInletWQ', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[InletWqOut]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_general_data_get_model_precision_get(self, **kwargs):  # noqa: E501
        """获取指定时间段内的模型精度统计数据 Get model precison statistic data of a certain period  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_general_data_get_model_precision_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str start_time: 开始时间 start time
        :param str end_time: 结束时间 end time
        :param str model_name: 模板模型名称 template model name
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[ModelPrecision]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_general_data_get_model_precision_get_with_http_info(**kwargs)  # noqa: E501

    def api_general_data_get_model_precision_get_with_http_info(self, **kwargs):  # noqa: E501
        """获取指定时间段内的模型精度统计数据 Get model precison statistic data of a certain period  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_general_data_get_model_precision_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str start_time: 开始时间 start time
        :param str end_time: 结束时间 end time
        :param str model_name: 模板模型名称 template model name
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[ModelPrecision], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'start_time',
            'end_time',
            'model_name'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_general_data_get_model_precision_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'start_time' in local_var_params and local_var_params['start_time'] is not None:  # noqa: E501
            query_params.append(('startTime', local_var_params['start_time']))  # noqa: E501
        if 'end_time' in local_var_params and local_var_params['end_time'] is not None:  # noqa: E501
            query_params.append(('endTime', local_var_params['end_time']))  # noqa: E501
        if 'model_name' in local_var_params and local_var_params['model_name'] is not None:  # noqa: E501
            query_params.append(('modelName', local_var_params['model_name']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/GeneralData/GetModelPrecision', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[ModelPrecision]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_general_data_get_optim_out_data_get(self, **kwargs):  # noqa: E501
        """获取优化建议 Get optimization recommendation data  # noqa: E501

        返回包括优化二沉池出水水质，优化控制建议 Secondary sedimentation tank effluent water quality statistic data and optimized control recommendation data will be returned.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_general_data_get_optim_out_data_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str start_time: 开始时间 start time
        :param str end_time: 结束时间 end time
        :param str product_line: 工艺线代码 product line code
        :param str model_name: 模板模型名称 template model name
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ModelOptimDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_general_data_get_optim_out_data_get_with_http_info(**kwargs)  # noqa: E501

    def api_general_data_get_optim_out_data_get_with_http_info(self, **kwargs):  # noqa: E501
        """获取优化建议 Get optimization recommendation data  # noqa: E501

        返回包括优化二沉池出水水质，优化控制建议 Secondary sedimentation tank effluent water quality statistic data and optimized control recommendation data will be returned.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_general_data_get_optim_out_data_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str start_time: 开始时间 start time
        :param str end_time: 结束时间 end time
        :param str product_line: 工艺线代码 product line code
        :param str model_name: 模板模型名称 template model name
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ModelOptimDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'start_time',
            'end_time',
            'product_line',
            'model_name'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_general_data_get_optim_out_data_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'start_time' in local_var_params and local_var_params['start_time'] is not None:  # noqa: E501
            query_params.append(('startTime', local_var_params['start_time']))  # noqa: E501
        if 'end_time' in local_var_params and local_var_params['end_time'] is not None:  # noqa: E501
            query_params.append(('endTime', local_var_params['end_time']))  # noqa: E501
        if 'product_line' in local_var_params and local_var_params['product_line'] is not None:  # noqa: E501
            query_params.append(('productLine', local_var_params['product_line']))  # noqa: E501
        if 'model_name' in local_var_params and local_var_params['model_name'] is not None:  # noqa: E501
            query_params.append(('modelName', local_var_params['model_name']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/GeneralData/GetOptimOutData', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ModelOptimDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_general_data_get_outlet_wq_get(self, **kwargs):  # noqa: E501
        """获取出水水质数据，包括在线数据和模拟结果数据 Get effluent water quality data, including online processed data and model result data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_general_data_get_outlet_wq_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str start_time: 开始时间 start time
        :param str end_time: 结束时间 end time
        :param str model_name: 模板模型名称 template model name
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[OutletWqOut]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_general_data_get_outlet_wq_get_with_http_info(**kwargs)  # noqa: E501

    def api_general_data_get_outlet_wq_get_with_http_info(self, **kwargs):  # noqa: E501
        """获取出水水质数据，包括在线数据和模拟结果数据 Get effluent water quality data, including online processed data and model result data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_general_data_get_outlet_wq_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str start_time: 开始时间 start time
        :param str end_time: 结束时间 end time
        :param str model_name: 模板模型名称 template model name
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[OutletWqOut], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'start_time',
            'end_time',
            'model_name'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_general_data_get_outlet_wq_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'start_time' in local_var_params and local_var_params['start_time'] is not None:  # noqa: E501
            query_params.append(('startTime', local_var_params['start_time']))  # noqa: E501
        if 'end_time' in local_var_params and local_var_params['end_time'] is not None:  # noqa: E501
            query_params.append(('endTime', local_var_params['end_time']))  # noqa: E501
        if 'model_name' in local_var_params and local_var_params['model_name'] is not None:  # noqa: E501
            query_params.append(('modelName', local_var_params['model_name']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/GeneralData/GetOutletWQ', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[OutletWqOut]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_general_data_get_predict_alarm_get(self, **kwargs):  # noqa: E501
        """获取进出水水质预警信息 Get alarm data for inlet and outlet water quality  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_general_data_get_predict_alarm_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str start_time: 开始时间 start time
        :param str end_time: 结束时间 end time
        :param list[str] alarm_types: 消息类型 alarm types
        :param str is_national_standard: 是否获取国标 true indicates grade=1, and false indicates grade!=1
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[PredictAlarmOut]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_general_data_get_predict_alarm_get_with_http_info(**kwargs)  # noqa: E501

    def api_general_data_get_predict_alarm_get_with_http_info(self, **kwargs):  # noqa: E501
        """获取进出水水质预警信息 Get alarm data for inlet and outlet water quality  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_general_data_get_predict_alarm_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str start_time: 开始时间 start time
        :param str end_time: 结束时间 end time
        :param list[str] alarm_types: 消息类型 alarm types
        :param str is_national_standard: 是否获取国标 true indicates grade=1, and false indicates grade!=1
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[PredictAlarmOut], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'start_time',
            'end_time',
            'alarm_types',
            'is_national_standard'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_general_data_get_predict_alarm_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'start_time' in local_var_params and local_var_params['start_time'] is not None:  # noqa: E501
            query_params.append(('StartTime', local_var_params['start_time']))  # noqa: E501
        if 'end_time' in local_var_params and local_var_params['end_time'] is not None:  # noqa: E501
            query_params.append(('EndTime', local_var_params['end_time']))  # noqa: E501
        if 'alarm_types' in local_var_params and local_var_params['alarm_types'] is not None:  # noqa: E501
            query_params.append(('AlarmTypes', local_var_params['alarm_types']))  # noqa: E501
            collection_formats['AlarmTypes'] = 'multi'  # noqa: E501
        if 'is_national_standard' in local_var_params and local_var_params['is_national_standard'] is not None:  # noqa: E501
            query_params.append(('IsNationalStandard', local_var_params['is_national_standard']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/GeneralData/GetPredictAlarm', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[PredictAlarmOut]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v2_output_chemical_cost_get(self, **kwargs):  # noqa: E501
        """根据实际投药量，获取吨水药耗统计信息 Get dosage cost per ton of inflow water statistic result based on actual dosage  # noqa: E501

        返回过去七天，每天每条工艺线上的碳源加药吨水药耗和MCCR加药吨水药耗 Carbon source doage cost per ton of water and MCCR dosage cost per ton of water of each product line and each day in the past seven days will be returned.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v2_output_chemical_cost_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str model_name: 模型名称 template model name
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[ChemicalCostPerFlowOutput]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v2_output_chemical_cost_get_with_http_info(**kwargs)  # noqa: E501

    def api_v2_output_chemical_cost_get_with_http_info(self, **kwargs):  # noqa: E501
        """根据实际投药量，获取吨水药耗统计信息 Get dosage cost per ton of inflow water statistic result based on actual dosage  # noqa: E501

        返回过去七天，每天每条工艺线上的碳源加药吨水药耗和MCCR加药吨水药耗 Carbon source doage cost per ton of water and MCCR dosage cost per ton of water of each product line and each day in the past seven days will be returned.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v2_output_chemical_cost_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str model_name: 模型名称 template model name
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[ChemicalCostPerFlowOutput], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'model_name'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v2_output_chemical_cost_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'model_name' in local_var_params and local_var_params['model_name'] is not None:  # noqa: E501
            query_params.append(('modelName', local_var_params['model_name']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/output/chemical-cost', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[ChemicalCostPerFlowOutput]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v2_output_data_boards_get(self, **kwargs):  # noqa: E501
        """获取数据看板统计数据 Get statistic data for data board  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v2_output_data_boards_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[DataBoardFullOut]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v2_output_data_boards_get_with_http_info(**kwargs)  # noqa: E501

    def api_v2_output_data_boards_get_with_http_info(self, **kwargs):  # noqa: E501
        """获取数据看板统计数据 Get statistic data for data board  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v2_output_data_boards_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[DataBoardFullOut], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v2_output_data_boards_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/output/data-boards', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[DataBoardFullOut]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v2_output_device_maintenance_get(self, **kwargs):  # noqa: E501
        """查询关键设备维护预警信息 Get key device maintenance warning information  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v2_output_device_maintenance_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str start_time: 开始时间 start time
        :param str end_time: 结束时间 end time
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[DeviceMaintenanceOutput]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v2_output_device_maintenance_get_with_http_info(**kwargs)  # noqa: E501

    def api_v2_output_device_maintenance_get_with_http_info(self, **kwargs):  # noqa: E501
        """查询关键设备维护预警信息 Get key device maintenance warning information  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v2_output_device_maintenance_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str start_time: 开始时间 start time
        :param str end_time: 结束时间 end time
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[DeviceMaintenanceOutput], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'start_time',
            'end_time'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v2_output_device_maintenance_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'start_time' in local_var_params and local_var_params['start_time'] is not None:  # noqa: E501
            query_params.append(('startTime', local_var_params['start_time']))  # noqa: E501
        if 'end_time' in local_var_params and local_var_params['end_time'] is not None:  # noqa: E501
            query_params.append(('endTime', local_var_params['end_time']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/output/device/maintenance', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[DeviceMaintenanceOutput]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v2_output_entire_process_ts_by_productline_get(self, **kwargs):  # noqa: E501
        """通过生产线获取全流程水质 Get water quality entire process data by product line  # noqa: E501

        查询指定时间段内，所有指标在每一个工艺单元上的时间序列结果数据，包括进水、各个生化池、出水 Get time-series result data of all the indicators on each process unit including inlet, biochemical pools and outlet of a certain period.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v2_output_entire_process_ts_by_productline_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str product_line: 工艺线代码 product line code
        :param str start_time: 开始时间 start time
        :param str end_time: 结束时间 end time
        :param str model_name: 模板模型名称 template model name
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[EntireProcessWqOut]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v2_output_entire_process_ts_by_productline_get_with_http_info(**kwargs)  # noqa: E501

    def api_v2_output_entire_process_ts_by_productline_get_with_http_info(self, **kwargs):  # noqa: E501
        """通过生产线获取全流程水质 Get water quality entire process data by product line  # noqa: E501

        查询指定时间段内，所有指标在每一个工艺单元上的时间序列结果数据，包括进水、各个生化池、出水 Get time-series result data of all the indicators on each process unit including inlet, biochemical pools and outlet of a certain period.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v2_output_entire_process_ts_by_productline_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str product_line: 工艺线代码 product line code
        :param str start_time: 开始时间 start time
        :param str end_time: 结束时间 end time
        :param str model_name: 模板模型名称 template model name
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[EntireProcessWqOut], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'product_line',
            'start_time',
            'end_time',
            'model_name'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v2_output_entire_process_ts_by_productline_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'product_line' in local_var_params and local_var_params['product_line'] is not None:  # noqa: E501
            query_params.append(('productLine', local_var_params['product_line']))  # noqa: E501
        if 'start_time' in local_var_params and local_var_params['start_time'] is not None:  # noqa: E501
            query_params.append(('startTime', local_var_params['start_time']))  # noqa: E501
        if 'end_time' in local_var_params and local_var_params['end_time'] is not None:  # noqa: E501
            query_params.append(('endTime', local_var_params['end_time']))  # noqa: E501
        if 'model_name' in local_var_params and local_var_params['model_name'] is not None:  # noqa: E501
            query_params.append(('modelName', local_var_params['model_name']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/output/entire-process/ts-by-productline', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[EntireProcessWqOut]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v2_output_refresh_data_boards_get(self, **kwargs):  # noqa: E501
        """定时统计看板数据  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v2_output_refresh_data_boards_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str tenant_id:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: StatisDataBoardsView
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v2_output_refresh_data_boards_get_with_http_info(**kwargs)  # noqa: E501

    def api_v2_output_refresh_data_boards_get_with_http_info(self, **kwargs):  # noqa: E501
        """定时统计看板数据  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v2_output_refresh_data_boards_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str tenant_id:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(StatisDataBoardsView, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'tenant_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v2_output_refresh_data_boards_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'tenant_id' in local_var_params and local_var_params['tenant_id'] is not None:  # noqa: E501
            query_params.append(('tenantId', local_var_params['tenant_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/output/refresh-data-boards', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='StatisDataBoardsView',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    model-configuration-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_model_configuration_service.configuration import Configuration


class QueryStatusOutput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'step_code': 'str',
        'description': 'str',
        'status': 'ProjectInitializeStatusEnum',
        'execute_time': 'datetime',
        'param': 'str',
        'project_name': 'str',
        'step': 'ProjectInitializeStepEnum'
    }

    attribute_map = {
        'step_code': 'stepCode',
        'description': 'description',
        'status': 'status',
        'execute_time': 'executeTime',
        'param': 'param',
        'project_name': 'projectName',
        'step': 'step'
    }

    def __init__(self, step_code=None, description=None, status=None, execute_time=None, param=None, project_name=None, step=None, local_vars_configuration=None):  # noqa: E501
        """QueryStatusOutput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._step_code = None
        self._description = None
        self._status = None
        self._execute_time = None
        self._param = None
        self._project_name = None
        self._step = None
        self.discriminator = None

        self.step_code = step_code
        self.description = description
        if status is not None:
            self.status = status
        if execute_time is not None:
            self.execute_time = execute_time
        self.param = param
        self.project_name = project_name
        if step is not None:
            self.step = step

    @property
    def step_code(self):
        """Gets the step_code of this QueryStatusOutput.  # noqa: E501

        初始化步骤的代码 project initialization step code  # noqa: E501

        :return: The step_code of this QueryStatusOutput.  # noqa: E501
        :rtype: str
        """
        return self._step_code

    @step_code.setter
    def step_code(self, step_code):
        """Sets the step_code of this QueryStatusOutput.

        初始化步骤的代码 project initialization step code  # noqa: E501

        :param step_code: The step_code of this QueryStatusOutput.  # noqa: E501
        :type: str
        """

        self._step_code = step_code

    @property
    def description(self):
        """Gets the description of this QueryStatusOutput.  # noqa: E501

        初始化步骤的描述 initialization step description  # noqa: E501

        :return: The description of this QueryStatusOutput.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this QueryStatusOutput.

        初始化步骤的描述 initialization step description  # noqa: E501

        :param description: The description of this QueryStatusOutput.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def status(self):
        """Gets the status of this QueryStatusOutput.  # noqa: E501


        :return: The status of this QueryStatusOutput.  # noqa: E501
        :rtype: ProjectInitializeStatusEnum
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this QueryStatusOutput.


        :param status: The status of this QueryStatusOutput.  # noqa: E501
        :type: ProjectInitializeStatusEnum
        """

        self._status = status

    @property
    def execute_time(self):
        """Gets the execute_time of this QueryStatusOutput.  # noqa: E501

        初始化步骤的执行时间 initialization step execution time  # noqa: E501

        :return: The execute_time of this QueryStatusOutput.  # noqa: E501
        :rtype: datetime
        """
        return self._execute_time

    @execute_time.setter
    def execute_time(self, execute_time):
        """Sets the execute_time of this QueryStatusOutput.

        初始化步骤的执行时间 initialization step execution time  # noqa: E501

        :param execute_time: The execute_time of this QueryStatusOutput.  # noqa: E501
        :type: datetime
        """

        self._execute_time = execute_time

    @property
    def param(self):
        """Gets the param of this QueryStatusOutput.  # noqa: E501

        初始化步骤涉及的参数 the parameters of the step  # noqa: E501

        :return: The param of this QueryStatusOutput.  # noqa: E501
        :rtype: str
        """
        return self._param

    @param.setter
    def param(self, param):
        """Sets the param of this QueryStatusOutput.

        初始化步骤涉及的参数 the parameters of the step  # noqa: E501

        :param param: The param of this QueryStatusOutput.  # noqa: E501
        :type: str
        """

        self._param = param

    @property
    def project_name(self):
        """Gets the project_name of this QueryStatusOutput.  # noqa: E501

        项目名称 project name  # noqa: E501

        :return: The project_name of this QueryStatusOutput.  # noqa: E501
        :rtype: str
        """
        return self._project_name

    @project_name.setter
    def project_name(self, project_name):
        """Sets the project_name of this QueryStatusOutput.

        项目名称 project name  # noqa: E501

        :param project_name: The project_name of this QueryStatusOutput.  # noqa: E501
        :type: str
        """

        self._project_name = project_name

    @property
    def step(self):
        """Gets the step of this QueryStatusOutput.  # noqa: E501


        :return: The step of this QueryStatusOutput.  # noqa: E501
        :rtype: ProjectInitializeStepEnum
        """
        return self._step

    @step.setter
    def step(self, step):
        """Sets the step of this QueryStatusOutput.


        :param step: The step of this QueryStatusOutput.  # noqa: E501
        :type: ProjectInitializeStepEnum
        """

        self._step = step

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, QueryStatusOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, QueryStatusOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    model-information-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_model_information_service.configuration import Configuration


class FlushingParaDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'pipe_model_id': 'str',
        'from_node': 'str',
        'to_node': 'str',
        'target_velocity': 'float',
        'flushing_demand': 'float',
        'flushing_time': 'float',
        'id': 'str'
    }

    attribute_map = {
        'pipe_model_id': 'pipeModelId',
        'from_node': 'fromNode',
        'to_node': 'toNode',
        'target_velocity': 'targetVelocity',
        'flushing_demand': 'flushingDemand',
        'flushing_time': 'flushingTime',
        'id': 'id'
    }

    def __init__(self, pipe_model_id=None, from_node=None, to_node=None, target_velocity=None, flushing_demand=None, flushing_time=None, id=None, local_vars_configuration=None):  # noqa: E501
        """FlushingParaDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._pipe_model_id = None
        self._from_node = None
        self._to_node = None
        self._target_velocity = None
        self._flushing_demand = None
        self._flushing_time = None
        self._id = None
        self.discriminator = None

        self.pipe_model_id = pipe_model_id
        self.from_node = from_node
        self.to_node = to_node
        if target_velocity is not None:
            self.target_velocity = target_velocity
        if flushing_demand is not None:
            self.flushing_demand = flushing_demand
        if flushing_time is not None:
            self.flushing_time = flushing_time
        if id is not None:
            self.id = id

    @property
    def pipe_model_id(self):
        """Gets the pipe_model_id of this FlushingParaDto.  # noqa: E501

        模型中管道ID pipe muid  # noqa: E501

        :return: The pipe_model_id of this FlushingParaDto.  # noqa: E501
        :rtype: str
        """
        return self._pipe_model_id

    @pipe_model_id.setter
    def pipe_model_id(self, pipe_model_id):
        """Sets the pipe_model_id of this FlushingParaDto.

        模型中管道ID pipe muid  # noqa: E501

        :param pipe_model_id: The pipe_model_id of this FlushingParaDto.  # noqa: E501
        :type: str
        """

        self._pipe_model_id = pipe_model_id

    @property
    def from_node(self):
        """Gets the from_node of this FlushingParaDto.  # noqa: E501

        流入节点 flush from node  # noqa: E501

        :return: The from_node of this FlushingParaDto.  # noqa: E501
        :rtype: str
        """
        return self._from_node

    @from_node.setter
    def from_node(self, from_node):
        """Sets the from_node of this FlushingParaDto.

        流入节点 flush from node  # noqa: E501

        :param from_node: The from_node of this FlushingParaDto.  # noqa: E501
        :type: str
        """

        self._from_node = from_node

    @property
    def to_node(self):
        """Gets the to_node of this FlushingParaDto.  # noqa: E501

        流出节点 flush to node  # noqa: E501

        :return: The to_node of this FlushingParaDto.  # noqa: E501
        :rtype: str
        """
        return self._to_node

    @to_node.setter
    def to_node(self, to_node):
        """Sets the to_node of this FlushingParaDto.

        流出节点 flush to node  # noqa: E501

        :param to_node: The to_node of this FlushingParaDto.  # noqa: E501
        :type: str
        """

        self._to_node = to_node

    @property
    def target_velocity(self):
        """Gets the target_velocity of this FlushingParaDto.  # noqa: E501

        目标流速 target velocity  # noqa: E501

        :return: The target_velocity of this FlushingParaDto.  # noqa: E501
        :rtype: float
        """
        return self._target_velocity

    @target_velocity.setter
    def target_velocity(self, target_velocity):
        """Sets the target_velocity of this FlushingParaDto.

        目标流速 target velocity  # noqa: E501

        :param target_velocity: The target_velocity of this FlushingParaDto.  # noqa: E501
        :type: float
        """

        self._target_velocity = target_velocity

    @property
    def flushing_demand(self):
        """Gets the flushing_demand of this FlushingParaDto.  # noqa: E501

        冲洗流量 flushing demand  # noqa: E501

        :return: The flushing_demand of this FlushingParaDto.  # noqa: E501
        :rtype: float
        """
        return self._flushing_demand

    @flushing_demand.setter
    def flushing_demand(self, flushing_demand):
        """Sets the flushing_demand of this FlushingParaDto.

        冲洗流量 flushing demand  # noqa: E501

        :param flushing_demand: The flushing_demand of this FlushingParaDto.  # noqa: E501
        :type: float
        """

        self._flushing_demand = flushing_demand

    @property
    def flushing_time(self):
        """Gets the flushing_time of this FlushingParaDto.  # noqa: E501

        冲洗时长 flushing time  # noqa: E501

        :return: The flushing_time of this FlushingParaDto.  # noqa: E501
        :rtype: float
        """
        return self._flushing_time

    @flushing_time.setter
    def flushing_time(self, flushing_time):
        """Sets the flushing_time of this FlushingParaDto.

        冲洗时长 flushing time  # noqa: E501

        :param flushing_time: The flushing_time of this FlushingParaDto.  # noqa: E501
        :type: float
        """

        self._flushing_time = flushing_time

    @property
    def id(self):
        """Gets the id of this FlushingParaDto.  # noqa: E501

        管道冲洗参数ID pipe flushing parameter id  # noqa: E501

        :return: The id of this FlushingParaDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this FlushingParaDto.

        管道冲洗参数ID pipe flushing parameter id  # noqa: E501

        :param id: The id of this FlushingParaDto.  # noqa: E501
        :type: str
        """

        self._id = id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FlushingParaDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FlushingParaDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa
"""
    wwtp-paas-main-bus-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from dhicn_wwtp_data_bus_service.models.abft_process_status_output import AbftProcessStatusOutput
from dhicn_wwtp_data_bus_service.models.add_model_precision_config_input import AddModelPrecisionConfigInput
from dhicn_wwtp_data_bus_service.models.add_pro_num_sim_lab_index_config_input import AddProNumSimLabIndexConfigInput
from dhicn_wwtp_data_bus_service.models.add_sys_statistic_configs_input import AddSysStatisticConfigsInput
from dhicn_wwtp_data_bus_service.models.alarm_config_in_out import AlarmConfigInOut
from dhicn_wwtp_data_bus_service.models.assembly_config_output import AssemblyConfigOutput
from dhicn_wwtp_data_bus_service.models.bio_value import BioValue
from dhicn_wwtp_data_bus_service.models.build_calc_dosage_config_in_out import BuildCalcDosageConfigInOut
from dhicn_wwtp_data_bus_service.models.catalysis_bf_output import CatalysisBfOutput
from dhicn_wwtp_data_bus_service.models.catalysis_tank_output import CatalysisTankOutput
from dhicn_wwtp_data_bus_service.models.cd_addition_rate_output import CdAdditionRateOutput
from dhicn_wwtp_data_bus_service.models.chemical_cost_per_flow_output import ChemicalCostPerFlowOutput
from dhicn_wwtp_data_bus_service.models.code_unit import CodeUnit
from dhicn_wwtp_data_bus_service.models.config_item import ConfigItem
from dhicn_wwtp_data_bus_service.models.control_item import ControlItem
from dhicn_wwtp_data_bus_service.models.control_online_point_output import ControlOnlinePointOutput
from dhicn_wwtp_data_bus_service.models.cost_data import CostData
from dhicn_wwtp_data_bus_service.models.daily_accumulation_value import DailyAccumulationValue
from dhicn_wwtp_data_bus_service.models.data import Data
from dhicn_wwtp_data_bus_service.models.data_board_full_out import DataBoardFullOut
from dhicn_wwtp_data_bus_service.models.delete_scenario_input import DeleteScenarioInput
from dhicn_wwtp_data_bus_service.models.device_maintenance_output import DeviceMaintenanceOutput
from dhicn_wwtp_data_bus_service.models.dosing_log_output import DosingLogOutput
from dhicn_wwtp_data_bus_service.models.dosing_param_setting_dto import DosingParamSettingDto
from dhicn_wwtp_data_bus_service.models.dosing_parameter_output import DosingParameterOutput
from dhicn_wwtp_data_bus_service.models.dosing_statistic_dailys_in_out import DosingStatisticDailysInOut
from dhicn_wwtp_data_bus_service.models.dosing_statistic_dailys_output import DosingStatisticDailysOutput
from dhicn_wwtp_data_bus_service.models.dosing_statistic_monthlys_in_out import DosingStatisticMonthlysInOut
from dhicn_wwtp_data_bus_service.models.entire_process_ts import EntireProcessTs
from dhicn_wwtp_data_bus_service.models.entire_process_wq_out import EntireProcessWqOut
from dhicn_wwtp_data_bus_service.models.execute_plc_input import ExecutePlcInput
from dhicn_wwtp_data_bus_service.models.expression_info import ExpressionInfo
from dhicn_wwtp_data_bus_service.models.get_pro_num_sim_lab_index_config_output import GetProNumSimLabIndexConfigOutput
from dhicn_wwtp_data_bus_service.models.get_statistic_result_dto import GetStatisticResultDto
from dhicn_wwtp_data_bus_service.models.global_config_in_out import GlobalConfigInOut
from dhicn_wwtp_data_bus_service.models.group_data import GroupData
from dhicn_wwtp_data_bus_service.models.hp_display_config_in_out import HpDisplayConfigInOut
from dhicn_wwtp_data_bus_service.models.inlet_load_output import InletLoadOutput
from dhicn_wwtp_data_bus_service.models.inlet_parameters_output import InletParametersOutput
from dhicn_wwtp_data_bus_service.models.inlet_wq_out import InletWqOut
from dhicn_wwtp_data_bus_service.models.inline_object import InlineObject
from dhicn_wwtp_data_bus_service.models.inline_object1 import InlineObject1
from dhicn_wwtp_data_bus_service.models.intelligent_deni_config_in_out import IntelligentDeniConfigInOut
from dhicn_wwtp_data_bus_service.models.mapping_config_input_output import MappingConfigInputOutput
from dhicn_wwtp_data_bus_service.models.micro_organism_output import MicroOrganismOutput
from dhicn_wwtp_data_bus_service.models.model_node_config_input_output import ModelNodeConfigInputOutput
from dhicn_wwtp_data_bus_service.models.model_optim_dto import ModelOptimDto
from dhicn_wwtp_data_bus_service.models.model_param import ModelParam
from dhicn_wwtp_data_bus_service.models.model_precision import ModelPrecision
from dhicn_wwtp_data_bus_service.models.model_precision_configs_dto import ModelPrecisionConfigsDto
from dhicn_wwtp_data_bus_service.models.online_point_config_input_output import OnlinePointConfigInputOutput
from dhicn_wwtp_data_bus_service.models.outlet_tn_output import OutletTnOutput
from dhicn_wwtp_data_bus_service.models.outlet_wq_out import OutletWqOut
from dhicn_wwtp_data_bus_service.models.percentages_dto import PercentagesDto
from dhicn_wwtp_data_bus_service.models.point_value import PointValue
from dhicn_wwtp_data_bus_service.models.precision_wq import PrecisionWq
from dhicn_wwtp_data_bus_service.models.predict_alarm_out import PredictAlarmOut
from dhicn_wwtp_data_bus_service.models.processed_setting_dto import ProcessedSettingDto
from dhicn_wwtp_data_bus_service.models.query_biochemicaltanks_output import QueryBiochemicaltanksOutput
from dhicn_wwtp_data_bus_service.models.query_by_condition_input import QueryByConditionInput
from dhicn_wwtp_data_bus_service.models.query_control_param_compare_input import QueryControlParamCompareInput
from dhicn_wwtp_data_bus_service.models.query_control_param_compare_output import QueryControlParamCompareOutput
from dhicn_wwtp_data_bus_service.models.query_indicator_statistic_output import QueryIndicatorStatisticOutput
from dhicn_wwtp_data_bus_service.models.query_inlet_data_output import QueryInletDataOutput
from dhicn_wwtp_data_bus_service.models.real_time_data import RealTimeData
from dhicn_wwtp_data_bus_service.models.real_time_output import RealTimeOutput
from dhicn_wwtp_data_bus_service.models.remote_service_error_info import RemoteServiceErrorInfo
from dhicn_wwtp_data_bus_service.models.remote_service_error_response import RemoteServiceErrorResponse
from dhicn_wwtp_data_bus_service.models.remote_service_validation_error_info import RemoteServiceValidationErrorInfo
from dhicn_wwtp_data_bus_service.models.result_param import ResultParam
from dhicn_wwtp_data_bus_service.models.result_setting import ResultSetting
from dhicn_wwtp_data_bus_service.models.save_inlet_data_input import SaveInletDataInput
from dhicn_wwtp_data_bus_service.models.save_param_input import SaveParamInput
from dhicn_wwtp_data_bus_service.models.scenario import Scenario
from dhicn_wwtp_data_bus_service.models.scenario_model_node_dto import ScenarioModelNodeDto
from dhicn_wwtp_data_bus_service.models.select_item_node import SelectItemNode
from dhicn_wwtp_data_bus_service.models.select_item_node_detail_info import SelectItemNodeDetailInfo
from dhicn_wwtp_data_bus_service.models.sim_results_outupt import SimResultsOutupt
from dhicn_wwtp_data_bus_service.models.single_code_datas_output import SingleCodeDatasOutput
from dhicn_wwtp_data_bus_service.models.statis_data_boards_view import StatisDataBoardsView
from dhicn_wwtp_data_bus_service.models.statistic_data import StatisticData
from dhicn_wwtp_data_bus_service.models.statistic_var_ref_dto import StatisticVarRefDto
from dhicn_wwtp_data_bus_service.models.string_list_result import StringListResult
from dhicn_wwtp_data_bus_service.models.svr_point_info import SvrPointInfo
from dhicn_wwtp_data_bus_service.models.sys_code_config_input_output import SysCodeConfigInputOutput
from dhicn_wwtp_data_bus_service.models.sys_statistic_config import SysStatisticConfig
from dhicn_wwtp_data_bus_service.models.sys_statistic_config_in_out import SysStatisticConfigInOut
from dhicn_wwtp_data_bus_service.models.toxic_alarms_output import ToxicAlarmsOutput
from dhicn_wwtp_data_bus_service.models.toxicity_input import ToxicityInput
from dhicn_wwtp_data_bus_service.models.toxicity_output import ToxicityOutput
from dhicn_wwtp_data_bus_service.models.ts_data import TsData
from dhicn_wwtp_data_bus_service.models.ts_data_output import TsDataOutput
from dhicn_wwtp_data_bus_service.models.ts_pair import TsPair
from dhicn_wwtp_data_bus_service.models.ts_pair1 import TsPair1
from dhicn_wwtp_data_bus_service.models.update_sys_statistic_configs_input import UpdateSysStatisticConfigsInput
from dhicn_wwtp_data_bus_service.models.update_wq_input_data_input import UpdateWqInputDataInput
from dhicn_wwtp_data_bus_service.models.wq_online_data_input import WqOnlineDataInput
from dhicn_wwtp_data_bus_service.models.wq_online_data_output import WqOnlineDataOutput
from dhicn_wwtp_data_bus_service.models.wq_online_point import WqOnlinePoint
from dhicn_wwtp_data_bus_service.models.wq_online_point_output import WqOnlinePointOutput
from dhicn_wwtp_data_bus_service.models.wq_simulation_indicator_input import WqSimulationIndicatorInput
from dhicn_wwtp_data_bus_service.models.wq_simulation_indicator_output import WqSimulationIndicatorOutput
from dhicn_wwtp_data_bus_service.models.wq_statistic_output import WqStatisticOutput



# coding: utf-8

"""
    model-configuration-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_model_configuration_service.configuration import Configuration


class CreateTemplateFileInputV2(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'mupp_name': 'str',
        'file_id': 'str',
        'system_id': 'str',
        'library_type': 'LibraryTypeEnum',
        'business_type': 'BusinessTypeEnum',
        'model_type': 'ModelTypeEnum'
    }

    attribute_map = {
        'mupp_name': 'muppName',
        'file_id': 'fileId',
        'system_id': 'systemId',
        'library_type': 'libraryType',
        'business_type': 'businessType',
        'model_type': 'modelType'
    }

    def __init__(self, mupp_name=None, file_id=None, system_id=None, library_type=None, business_type=None, model_type=None, local_vars_configuration=None):  # noqa: E501
        """CreateTemplateFileInputV2 - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._mupp_name = None
        self._file_id = None
        self._system_id = None
        self._library_type = None
        self._business_type = None
        self._model_type = None
        self.discriminator = None

        self.mupp_name = mupp_name
        if file_id is not None:
            self.file_id = file_id
        self.system_id = system_id
        if library_type is not None:
            self.library_type = library_type
        if business_type is not None:
            self.business_type = business_type
        if model_type is not None:
            self.model_type = model_type

    @property
    def mupp_name(self):
        """Gets the mupp_name of this CreateTemplateFileInputV2.  # noqa: E501

        模型文件名称 model file name without path  # noqa: E501

        :return: The mupp_name of this CreateTemplateFileInputV2.  # noqa: E501
        :rtype: str
        """
        return self._mupp_name

    @mupp_name.setter
    def mupp_name(self, mupp_name):
        """Sets the mupp_name of this CreateTemplateFileInputV2.

        模型文件名称 model file name without path  # noqa: E501

        :param mupp_name: The mupp_name of this CreateTemplateFileInputV2.  # noqa: E501
        :type: str
        """

        self._mupp_name = mupp_name

    @property
    def file_id(self):
        """Gets the file_id of this CreateTemplateFileInputV2.  # noqa: E501

        上传的文件的ID upload file id  # noqa: E501

        :return: The file_id of this CreateTemplateFileInputV2.  # noqa: E501
        :rtype: str
        """
        return self._file_id

    @file_id.setter
    def file_id(self, file_id):
        """Sets the file_id of this CreateTemplateFileInputV2.

        上传的文件的ID upload file id  # noqa: E501

        :param file_id: The file_id of this CreateTemplateFileInputV2.  # noqa: E501
        :type: str
        """

        self._file_id = file_id

    @property
    def system_id(self):
        """Gets the system_id of this CreateTemplateFileInputV2.  # noqa: E501

        系统ID system id  # noqa: E501

        :return: The system_id of this CreateTemplateFileInputV2.  # noqa: E501
        :rtype: str
        """
        return self._system_id

    @system_id.setter
    def system_id(self, system_id):
        """Sets the system_id of this CreateTemplateFileInputV2.

        系统ID system id  # noqa: E501

        :param system_id: The system_id of this CreateTemplateFileInputV2.  # noqa: E501
        :type: str
        """

        self._system_id = system_id

    @property
    def library_type(self):
        """Gets the library_type of this CreateTemplateFileInputV2.  # noqa: E501


        :return: The library_type of this CreateTemplateFileInputV2.  # noqa: E501
        :rtype: LibraryTypeEnum
        """
        return self._library_type

    @library_type.setter
    def library_type(self, library_type):
        """Sets the library_type of this CreateTemplateFileInputV2.


        :param library_type: The library_type of this CreateTemplateFileInputV2.  # noqa: E501
        :type: LibraryTypeEnum
        """

        self._library_type = library_type

    @property
    def business_type(self):
        """Gets the business_type of this CreateTemplateFileInputV2.  # noqa: E501


        :return: The business_type of this CreateTemplateFileInputV2.  # noqa: E501
        :rtype: BusinessTypeEnum
        """
        return self._business_type

    @business_type.setter
    def business_type(self, business_type):
        """Sets the business_type of this CreateTemplateFileInputV2.


        :param business_type: The business_type of this CreateTemplateFileInputV2.  # noqa: E501
        :type: BusinessTypeEnum
        """

        self._business_type = business_type

    @property
    def model_type(self):
        """Gets the model_type of this CreateTemplateFileInputV2.  # noqa: E501


        :return: The model_type of this CreateTemplateFileInputV2.  # noqa: E501
        :rtype: ModelTypeEnum
        """
        return self._model_type

    @model_type.setter
    def model_type(self, model_type):
        """Sets the model_type of this CreateTemplateFileInputV2.


        :param model_type: The model_type of this CreateTemplateFileInputV2.  # noqa: E501
        :type: ModelTypeEnum
        """

        self._model_type = model_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateTemplateFileInputV2):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateTemplateFileInputV2):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    wwtp-paas-main-bus-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_wwtp_data_bus_service.configuration import Configuration


class MappingConfigInputOutput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'point_code': 'str',
        'model_node_code': 'str',
        'sys_id': 'str',
        'default_value': 'float',
        'reserve': 'str'
    }

    attribute_map = {
        'id': 'id',
        'point_code': 'pointCode',
        'model_node_code': 'modelNodeCode',
        'sys_id': 'sysId',
        'default_value': 'defaultValue',
        'reserve': 'reserve'
    }

    def __init__(self, id=None, point_code=None, model_node_code=None, sys_id=None, default_value=None, reserve=None, local_vars_configuration=None):  # noqa: E501
        """MappingConfigInputOutput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._point_code = None
        self._model_node_code = None
        self._sys_id = None
        self._default_value = None
        self._reserve = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.point_code = point_code
        self.model_node_code = model_node_code
        if sys_id is not None:
            self.sys_id = sys_id
        if default_value is not None:
            self.default_value = default_value
        self.reserve = reserve

    @property
    def id(self):
        """Gets the id of this MappingConfigInputOutput.  # noqa: E501

        点位ID  # noqa: E501

        :return: The id of this MappingConfigInputOutput.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this MappingConfigInputOutput.

        点位ID  # noqa: E501

        :param id: The id of this MappingConfigInputOutput.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def point_code(self):
        """Gets the point_code of this MappingConfigInputOutput.  # noqa: E501

        系统点位编码  # noqa: E501

        :return: The point_code of this MappingConfigInputOutput.  # noqa: E501
        :rtype: str
        """
        return self._point_code

    @point_code.setter
    def point_code(self, point_code):
        """Sets the point_code of this MappingConfigInputOutput.

        系统点位编码  # noqa: E501

        :param point_code: The point_code of this MappingConfigInputOutput.  # noqa: E501
        :type: str
        """

        self._point_code = point_code

    @property
    def model_node_code(self):
        """Gets the model_node_code of this MappingConfigInputOutput.  # noqa: E501

        模型点位编码  # noqa: E501

        :return: The model_node_code of this MappingConfigInputOutput.  # noqa: E501
        :rtype: str
        """
        return self._model_node_code

    @model_node_code.setter
    def model_node_code(self, model_node_code):
        """Sets the model_node_code of this MappingConfigInputOutput.

        模型点位编码  # noqa: E501

        :param model_node_code: The model_node_code of this MappingConfigInputOutput.  # noqa: E501
        :type: str
        """

        self._model_node_code = model_node_code

    @property
    def sys_id(self):
        """Gets the sys_id of this MappingConfigInputOutput.  # noqa: E501

        系统点位ID  # noqa: E501

        :return: The sys_id of this MappingConfigInputOutput.  # noqa: E501
        :rtype: str
        """
        return self._sys_id

    @sys_id.setter
    def sys_id(self, sys_id):
        """Sets the sys_id of this MappingConfigInputOutput.

        系统点位ID  # noqa: E501

        :param sys_id: The sys_id of this MappingConfigInputOutput.  # noqa: E501
        :type: str
        """

        self._sys_id = sys_id

    @property
    def default_value(self):
        """Gets the default_value of this MappingConfigInputOutput.  # noqa: E501

        默认值  # noqa: E501

        :return: The default_value of this MappingConfigInputOutput.  # noqa: E501
        :rtype: float
        """
        return self._default_value

    @default_value.setter
    def default_value(self, default_value):
        """Sets the default_value of this MappingConfigInputOutput.

        默认值  # noqa: E501

        :param default_value: The default_value of this MappingConfigInputOutput.  # noqa: E501
        :type: float
        """

        self._default_value = default_value

    @property
    def reserve(self):
        """Gets the reserve of this MappingConfigInputOutput.  # noqa: E501

        保留字段  # noqa: E501

        :return: The reserve of this MappingConfigInputOutput.  # noqa: E501
        :rtype: str
        """
        return self._reserve

    @reserve.setter
    def reserve(self, reserve):
        """Sets the reserve of this MappingConfigInputOutput.

        保留字段  # noqa: E501

        :param reserve: The reserve of this MappingConfigInputOutput.  # noqa: E501
        :type: str
        """

        self._reserve = reserve

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MappingConfigInputOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MappingConfigInputOutput):
            return True

        return self.to_dict() != other.to_dict()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from dhicn_digital_twin_service.api.da_config_api import DAConfigApi
from dhicn_digital_twin_service.api.device_indicator_api import DeviceIndicatorApi
from dhicn_digital_twin_service.api.model_boundary_api import ModelBoundaryApi
from dhicn_digital_twin_service.api.model_point_api import ModelPointApi
from dhicn_digital_twin_service.api.point_data_type_map_api import PointDataTypeMapApi
from dhicn_digital_twin_service.api.point_map_api import PointMapApi
from dhicn_digital_twin_service.api.static_config_api import StaticConfigApi
